@@ -1,21 +1,21 @@
-use cassandra::iterator::ColumnIterator;
-use cassandra::iterator::FieldIterator;
+use crate::cassandra::iterator::ColumnIterator;
+use crate::cassandra::iterator::FieldIterator;
 
-use cassandra::schema::column_meta::ColumnMeta;
-use cassandra::util::Protected;
-use cassandra::value::Value;
-use cassandra_sys::CassTableMeta as _CassTableMeta;
-use cassandra_sys::cass_iterator_columns_from_table_meta;
-use cassandra_sys::cass_iterator_fields_from_table_meta;
-use cassandra_sys::cass_table_meta_clustering_key;
-use cassandra_sys::cass_table_meta_clustering_key_count;
-use cassandra_sys::cass_table_meta_column;
-use cassandra_sys::cass_table_meta_column_by_name;
-use cassandra_sys::cass_table_meta_column_count;
-use cassandra_sys::cass_table_meta_field_by_name;
-use cassandra_sys::cass_table_meta_name;
-use cassandra_sys::cass_table_meta_partition_key;
-use cassandra_sys::cass_table_meta_partition_key_count;
+use crate::cassandra::schema::column_meta::ColumnMeta;
+use crate::cassandra::util::Protected;
+use crate::cassandra::value::Value;
+use crate::cassandra_sys::cass_iterator_columns_from_table_meta;
+use crate::cassandra_sys::cass_iterator_fields_from_table_meta;
+use crate::cassandra_sys::cass_table_meta_clustering_key;
+use crate::cassandra_sys::cass_table_meta_clustering_key_count;
+use crate::cassandra_sys::cass_table_meta_column;
+use crate::cassandra_sys::cass_table_meta_column_by_name;
+use crate::cassandra_sys::cass_table_meta_column_count;
+use crate::cassandra_sys::cass_table_meta_field_by_name;
+use crate::cassandra_sys::cass_table_meta_name;
+use crate::cassandra_sys::cass_table_meta_partition_key;
+use crate::cassandra_sys::cass_table_meta_partition_key_count;
+use crate::cassandra_sys::CassTableMeta as _CassTableMeta;
 use std::mem;
 use std::slice;
 
@@ -26,8 +26,15 @@ use std::str;
 pub struct TableMeta(*const _CassTableMeta);
 
 impl Protected<*const _CassTableMeta> for TableMeta {
-    fn inner(&self) -> *const _CassTableMeta { self.0 }
-    fn build(inner: *const _CassTableMeta) -> Self { if inner.is_null() { panic!("Unexpected null pointer") }; TableMeta(inner) }
+    fn inner(&self) -> *const _CassTableMeta {
+        self.0
+    }
+    fn build(inner: *const _CassTableMeta) -> Self {
+        if inner.is_null() {
+            panic!("Unexpected null pointer")
+        };
+        TableMeta(inner)
+    }
 }
 
 impl TableMeta {
@@ -44,7 +51,12 @@ impl TableMeta {
     /// Gets the column metadata for the provided column name.
     pub fn column_by_name(&self, name: &str) -> ColumnMeta {
         // TODO: can return NULL
-        unsafe { ColumnMeta::build(cass_table_meta_column_by_name(self.0, name.as_ptr() as *const i8)) }
+        unsafe {
+            ColumnMeta::build(cass_table_meta_column_by_name(
+                self.0,
+                name.as_ptr() as *const i8,
+            ))
+        }
     }
 
     /// Gets the name of the table.
@@ -54,14 +66,19 @@ impl TableMeta {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
             cass_table_meta_name(self.0, &mut name, &mut name_length);
-            str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))
-                .expect("must be utf8")
-                .to_owned()
+            str::from_utf8(slice::from_raw_parts(
+                name as *const u8,
+                name_length as usize,
+            ))
+            .expect("must be utf8")
+            .to_owned()
         }
     }
 
     /// Gets the total number of columns for the table.
-    pub fn column_count(&self) -> usize { unsafe { cass_table_meta_column_count(self.0) } }
+    pub fn column_count(&self) -> usize {
+        unsafe { cass_table_meta_column_count(self.0) }
+    }
 
     /// Gets the column metadata for the provided index.
     pub fn column(&self, index: usize) -> ColumnMeta {
@@ -70,7 +87,9 @@ impl TableMeta {
     }
 
     /// Gets the number of columns for the table's partition key.
-    pub fn partition_key_count(&self) -> usize { unsafe { cass_table_meta_partition_key_count(self.0) } }
+    pub fn partition_key_count(&self) -> usize {
+        unsafe { cass_table_meta_partition_key_count(self.0) }
+    }
 
     /// Gets the partition key column metadata for the provided index.
     pub fn partition_key(&self, index: usize) -> Option<ColumnMeta> {
@@ -85,7 +104,9 @@ impl TableMeta {
     }
 
     /// Gets the number of columns for the table's clustering key
-    pub fn clustering_key_count(&self) -> usize { unsafe { cass_table_meta_clustering_key_count(self.0) } }
+    pub fn clustering_key_count(&self) -> usize {
+        unsafe { cass_table_meta_clustering_key_count(self.0) }
+    }
 
     /// Gets the clustering key column metadata for the provided index.
     pub fn cluster_key(&self, index: usize) -> Option<ColumnMeta> {
@@ -99,7 +120,6 @@ impl TableMeta {
         }
     }
 
-
     /// Gets a metadata field for the provided name. Metadata fields allow direct
     /// access to the column data found in the underlying "tables" metadata table.
     pub fn field_by_name(&self, name: &str) -> Option<Value> {
@@ -111,7 +131,6 @@ impl TableMeta {
             } else {
                 Some(Value::build(value))
             }
-
         }
     }
 }
