@@ -104,6 +104,58 @@ impl Uuid {
     }
 }
 
+impl From<uuid::Uuid> for Uuid {
+    fn from(id: uuid::Uuid) -> Uuid {
+        // implementation taken from Datastax C/C++ driver
+        // serialization.hpp, encode_uuid()
+        let input = id.as_bytes();
+
+        let mut time_and_version = 0u64;
+        time_and_version |= input[3] as u64;
+        time_and_version |= (input[2] as u64) << 8;
+        time_and_version |= (input[1] as u64) << 16;
+        time_and_version |= (input[0] as u64) << 24;
+
+        time_and_version |= (input[5] as u64) << 32;
+        time_and_version |= (input[4] as u64) << 40;
+
+        time_and_version |= (input[7] as u64) << 48;
+        time_and_version |= (input[6] as u64) << 56;
+
+        let mut clock_seq_and_node = 0u64;
+        for i in 0..8 {
+            clock_seq_and_node |= (input[15 - i] as u64) << (8 * i);
+        }
+        Uuid(_Uuid {
+            time_and_version,
+            clock_seq_and_node,
+        })
+    }
+}
+
+impl From<Uuid> for uuid::Uuid {
+    fn from(id: Uuid) -> uuid::Uuid {
+        // implementation taken from Datastax C/C++ driver
+        // serialization.hpp decode_uuid()
+        let mut output = [0u8; 16];
+        output[3] = id.0.time_and_version as u8;
+        output[2] = (id.0.time_and_version >> 8) as u8;
+        output[1] = (id.0.time_and_version >> 16) as u8;
+        output[0] = (id.0.time_and_version >> 24) as u8;
+
+        output[5] = (id.0.time_and_version >> 32) as u8;
+        output[4] = (id.0.time_and_version >> 40) as u8;
+
+        output[7] = (id.0.time_and_version >> 48) as u8;
+        output[6] = (id.0.time_and_version >> 56) as u8;
+
+        for i in 0..8 {
+            output[15 - i] = (id.0.clock_seq_and_node >> (8 * i)) as u8;
+        }
+        uuid::Uuid::from_bytes(&output).unwrap()
+    }
+}
+
 impl str::FromStr for Uuid {
     type Err = Error;
     fn from_str(str: &str) -> Result<Uuid> {
