@@ -1,71 +1,69 @@
+use crate::cassandra::data_type::ConstDataType;
+use crate::cassandra::error::*;
+use crate::cassandra::inet::Inet;
+use crate::cassandra::iterator::MapIterator;
+use crate::cassandra::iterator::SetIterator;
+use crate::cassandra::iterator::UserTypeIterator;
+use crate::cassandra::util::Protected;
+use crate::cassandra::uuid::Uuid;
 
-
-use cassandra::data_type::ConstDataType;
-use cassandra::inet::Inet;
-use cassandra::iterator::MapIterator;
-use cassandra::iterator::SetIterator;
-use cassandra::iterator::UserTypeIterator;
-use cassandra::util::Protected;
-use cassandra::uuid::Uuid;
-use cassandra::error::*;
-
-use cassandra_sys::CASS_ERROR_LIB_INVALID_VALUE_TYPE;
-use cassandra_sys::CASS_ERROR_LIB_NULL_VALUE;
-use cassandra_sys::CASS_VALUE_TYPE_ASCII;
-use cassandra_sys::CASS_VALUE_TYPE_BIGINT;
-use cassandra_sys::CASS_VALUE_TYPE_BLOB;
-use cassandra_sys::CASS_VALUE_TYPE_BOOLEAN;
-use cassandra_sys::CASS_VALUE_TYPE_COUNTER;
-use cassandra_sys::CASS_VALUE_TYPE_CUSTOM;
-use cassandra_sys::CASS_VALUE_TYPE_DATE;
-use cassandra_sys::CASS_VALUE_TYPE_DECIMAL;
-use cassandra_sys::CASS_VALUE_TYPE_DOUBLE;
-use cassandra_sys::CASS_VALUE_TYPE_FLOAT;
-use cassandra_sys::CASS_VALUE_TYPE_INET;
-use cassandra_sys::CASS_VALUE_TYPE_INT;
-use cassandra_sys::CASS_VALUE_TYPE_LAST_ENTRY;
-use cassandra_sys::CASS_VALUE_TYPE_LIST;
-use cassandra_sys::CASS_VALUE_TYPE_MAP;
-use cassandra_sys::CASS_VALUE_TYPE_SET;
-use cassandra_sys::CASS_VALUE_TYPE_SMALL_INT;
-use cassandra_sys::CASS_VALUE_TYPE_TEXT;
-use cassandra_sys::CASS_VALUE_TYPE_TIME;
-use cassandra_sys::CASS_VALUE_TYPE_TIMESTAMP;
-use cassandra_sys::CASS_VALUE_TYPE_TIMEUUID;
-use cassandra_sys::CASS_VALUE_TYPE_TINY_INT;
-use cassandra_sys::CASS_VALUE_TYPE_DURATION;
-use cassandra_sys::CASS_VALUE_TYPE_TUPLE;
-use cassandra_sys::CASS_VALUE_TYPE_UDT;
-use cassandra_sys::CASS_VALUE_TYPE_UNKNOWN;
-use cassandra_sys::CASS_VALUE_TYPE_UUID;
-use cassandra_sys::CASS_VALUE_TYPE_VARCHAR;
-use cassandra_sys::CASS_VALUE_TYPE_VARINT;
-use cassandra_sys::CassValue as _CassValue;
-use cassandra_sys::CassValueType_;
-use cassandra_sys::cass_collection_append_decimal;
-use cassandra_sys::cass_iterator_from_collection;
-use cassandra_sys::cass_iterator_from_map;
-use cassandra_sys::cass_iterator_fields_from_user_type;
-use cassandra_sys::cass_true;
-use cassandra_sys::cass_value_data_type;
-use cassandra_sys::cass_value_get_bool;
-use cassandra_sys::cass_value_get_bytes;
-use cassandra_sys::cass_value_get_double;
-use cassandra_sys::cass_value_get_float;
-use cassandra_sys::cass_value_get_inet;
-use cassandra_sys::cass_value_get_int16;
-use cassandra_sys::cass_value_get_int32;
-use cassandra_sys::cass_value_get_int64;
-use cassandra_sys::cass_value_get_int8;
-use cassandra_sys::cass_value_get_string;
-use cassandra_sys::cass_value_get_uint32;
-use cassandra_sys::cass_value_get_uuid;
-use cassandra_sys::cass_value_is_collection;
-use cassandra_sys::cass_value_is_null;
-use cassandra_sys::cass_value_item_count;
-use cassandra_sys::cass_value_primary_sub_type;
-use cassandra_sys::cass_value_secondary_sub_type;
-use cassandra_sys::cass_value_type;
+use crate::cassandra_sys::cass_collection_append_decimal;
+use crate::cassandra_sys::cass_iterator_fields_from_user_type;
+use crate::cassandra_sys::cass_iterator_from_collection;
+use crate::cassandra_sys::cass_iterator_from_map;
+use crate::cassandra_sys::cass_true;
+use crate::cassandra_sys::cass_value_data_type;
+use crate::cassandra_sys::cass_value_get_bool;
+use crate::cassandra_sys::cass_value_get_bytes;
+use crate::cassandra_sys::cass_value_get_double;
+use crate::cassandra_sys::cass_value_get_float;
+use crate::cassandra_sys::cass_value_get_inet;
+use crate::cassandra_sys::cass_value_get_int16;
+use crate::cassandra_sys::cass_value_get_int32;
+use crate::cassandra_sys::cass_value_get_int64;
+use crate::cassandra_sys::cass_value_get_int8;
+use crate::cassandra_sys::cass_value_get_string;
+use crate::cassandra_sys::cass_value_get_uint32;
+use crate::cassandra_sys::cass_value_get_uuid;
+use crate::cassandra_sys::cass_value_is_collection;
+use crate::cassandra_sys::cass_value_is_null;
+use crate::cassandra_sys::cass_value_item_count;
+use crate::cassandra_sys::cass_value_primary_sub_type;
+use crate::cassandra_sys::cass_value_secondary_sub_type;
+use crate::cassandra_sys::cass_value_type;
+use crate::cassandra_sys::CassValue as _CassValue;
+use crate::cassandra_sys::CassValueType_;
+use crate::cassandra_sys::CASS_ERROR_LIB_INVALID_VALUE_TYPE;
+use crate::cassandra_sys::CASS_ERROR_LIB_NULL_VALUE;
+use crate::cassandra_sys::CASS_VALUE_TYPE_ASCII;
+use crate::cassandra_sys::CASS_VALUE_TYPE_BIGINT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_BLOB;
+use crate::cassandra_sys::CASS_VALUE_TYPE_BOOLEAN;
+use crate::cassandra_sys::CASS_VALUE_TYPE_COUNTER;
+use crate::cassandra_sys::CASS_VALUE_TYPE_CUSTOM;
+use crate::cassandra_sys::CASS_VALUE_TYPE_DATE;
+use crate::cassandra_sys::CASS_VALUE_TYPE_DECIMAL;
+use crate::cassandra_sys::CASS_VALUE_TYPE_DOUBLE;
+use crate::cassandra_sys::CASS_VALUE_TYPE_DURATION;
+use crate::cassandra_sys::CASS_VALUE_TYPE_FLOAT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_INET;
+use crate::cassandra_sys::CASS_VALUE_TYPE_INT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_LAST_ENTRY;
+use crate::cassandra_sys::CASS_VALUE_TYPE_LIST;
+use crate::cassandra_sys::CASS_VALUE_TYPE_MAP;
+use crate::cassandra_sys::CASS_VALUE_TYPE_SET;
+use crate::cassandra_sys::CASS_VALUE_TYPE_SMALL_INT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TEXT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TIME;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TIMESTAMP;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TIMEUUID;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TINY_INT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_TUPLE;
+use crate::cassandra_sys::CASS_VALUE_TYPE_UDT;
+use crate::cassandra_sys::CASS_VALUE_TYPE_UNKNOWN;
+use crate::cassandra_sys::CASS_VALUE_TYPE_UUID;
+use crate::cassandra_sys::CASS_VALUE_TYPE_VARCHAR;
+use crate::cassandra_sys::CASS_VALUE_TYPE_VARINT;
 
 use std::ffi::CString;
 use std::fmt;
@@ -75,7 +73,6 @@ use std::ptr;
 use std::slice;
 use std::str;
 
-
 /// The type of a Cassandra value.
 #[derive(Debug, Eq, PartialEq, Copy, Clone, Hash)]
 #[allow(missing_docs)] // Meanings are defined in CQL documentation.
@@ -142,7 +139,6 @@ enhance_nullary_enum!(ValueType, CassValueType_, {
     (TUPLE, CASS_VALUE_TYPE_TUPLE, "TUPLE"),
 }, omit { CASS_VALUE_TYPE_LAST_ENTRY });
 
-
 /// A single primitive value or a collection of values.
 pub struct Value(*const _CassValue);
 
@@ -150,20 +146,31 @@ pub struct Value(*const _CassValue);
 unsafe impl Send for Value {}
 unsafe impl Sync for Value {}
 
-
 impl Protected<*const _CassValue> for Value {
-    fn inner(&self) -> *const _CassValue { self.0 }
-    fn build(inner: *const _CassValue) -> Self { if inner.is_null() { panic!("Unexpected null pointer") }; Value(inner) }
+    fn inner(&self) -> *const _CassValue {
+        self.0
+    }
+    fn build(inner: *const _CassValue) -> Self {
+        if inner.is_null() {
+            panic!("Unexpected null pointer")
+        };
+        Value(inner)
+    }
 }
 
 /// Write a set iterator to a formatter.
 pub(crate) fn write_set<F>(f: &mut Formatter, set: Result<SetIterator>, writer: F) -> fmt::Result
-    where F: Fn(&mut Formatter, Value) -> fmt::Result
+where
+    F: Fn(&mut Formatter, Value) -> fmt::Result,
 {
     write!(f, "[")?;
     match set {
         Err(_) => write!(f, "<error>")?,
-        Ok(iter) => for item in iter { writer(f, item)? },
+        Ok(iter) => {
+            for item in iter {
+                writer(f, item)?
+            }
+        }
     }
     write!(f, "]")?;
     Ok(())
@@ -171,19 +178,25 @@ pub(crate) fn write_set<F>(f: &mut Formatter, set: Result<SetIterator>, writer:
 
 /// Write a map iterator to a formatter.
 pub(crate) fn write_map<F>(f: &mut Formatter, set: Result<MapIterator>, writer: F) -> fmt::Result
-    where F: Fn(&mut Formatter, Value, Value) -> fmt::Result
+where
+    F: Fn(&mut Formatter, Value, Value) -> fmt::Result,
 {
     write!(f, "{{")?;
     match set {
         Err(_) => write!(f, "<error>")?,
-        Ok(iter) => for item in iter { writer(f, item.0, item.1)? },
+        Ok(iter) => {
+            for item in iter {
+                writer(f, item.0, item.1)?
+            }
+        }
     }
     write!(f, "}}")?;
     Ok(())
 }
 
 pub(crate) fn write_value<T, F>(f: &mut Formatter, v: Result<T>, writer: F) -> fmt::Result
-    where F: Fn(&mut Formatter, T) -> fmt::Result
+where
+    F: Fn(&mut Formatter, T) -> fmt::Result,
 {
     match v {
         Err(_) => write!(f, "<error>"),
@@ -199,9 +212,9 @@ impl Debug for Value {
             match self.get_type() {
                 ValueType::UNKNOWN => write!(f, "<unknown>"),
                 ValueType::CUSTOM => write!(f, "<custom>"),
-                ValueType::ASCII |
-                ValueType::TEXT |
-                ValueType::VARCHAR => write_value(f, self.get_string(), |f, v| write!(f, "{:?}", v)),
+                ValueType::ASCII | ValueType::TEXT | ValueType::VARCHAR => {
+                    write_value(f, self.get_string(), |f, v| write!(f, "{:?}", v))
+                }
                 ValueType::DECIMAL => write_value(f, self.get_bytes(), |f, v| write!(f, "{:?}", v)),
                 ValueType::COUNTER => write_value(f, self.get_i64(), |f, v| write!(f, "{:?}", v)),
                 ValueType::BIGINT => write_value(f, self.get_i64(), |f, v| write!(f, "{:?}", v)),
@@ -218,11 +231,16 @@ impl Debug for Value {
                 ValueType::DURATION => write_value(f, self.get_i32(), |f, v| write!(f, "{:?}", v)),
                 ValueType::INET => write_value(f, self.get_inet(), |f, v| write!(f, "{:?}", v)),
                 ValueType::TIMESTAMP => write_value(f, self.get_i64(), |f, v| write!(f, "{:?}", v)),
-                ValueType::TIMEUUID => write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID: {}", v)),
+                ValueType::TIMEUUID => {
+                    write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID: {}", v))
+                }
                 ValueType::UUID => write_value(f, self.get_uuid(), |f, v| write!(f, "UUID: {}", v)),
-                ValueType::SET |
-                ValueType::LIST => write_set(f, self.get_set(), |f, i| write!(f, "{:?}, ", i)),
-                ValueType::MAP => write_map(f, self.get_map(), |f, k, v| write!(f, "{:?} => {:?}, ", k, v)),
+                ValueType::SET | ValueType::LIST => {
+                    write_set(f, self.get_set(), |f, i| write!(f, "{:?}, ", i))
+                }
+                ValueType::MAP => write_map(f, self.get_map(), |f, k, v| {
+                    write!(f, "{:?} => {:?}, ", k, v)
+                }),
                 ValueType::UDT => write!(f, "<udt>"),
                 ValueType::TUPLE => write_set(f, self.get_set(), |f, i| write!(f, "{:?}, ", i)),
             }
@@ -238,30 +256,43 @@ impl Display for Value {
             match self.get_type() {
                 ValueType::UNKNOWN => write!(f, "{}", "unknown"),
                 ValueType::CUSTOM => write!(f, "{}", "custom"),
-                ValueType::ASCII |
-                ValueType::TEXT |
-                ValueType::VARCHAR => write_value(f, self.get_string(), |f, v| write!(f, "{}", v)),
-                ValueType::DECIMAL => write_value(f, self.get_bytes(), |f, v| write!(f, "DECIMAL:{:?}", v)),
+                ValueType::ASCII | ValueType::TEXT | ValueType::VARCHAR => {
+                    write_value(f, self.get_string(), |f, v| write!(f, "{}", v))
+                }
+                ValueType::DECIMAL => {
+                    write_value(f, self.get_bytes(), |f, v| write!(f, "DECIMAL:{:?}", v))
+                }
                 ValueType::COUNTER => write_value(f, self.get_i64(), |f, v| write!(f, "{}", v)),
                 ValueType::BIGINT => write_value(f, self.get_i64(), |f, v| write!(f, "{}", v)),
                 ValueType::DATE => write_value(f, self.get_string(), |f, v| write!(f, "{}", v)),
                 ValueType::TIME => write_value(f, self.get_string(), |f, v| write!(f, "{}", v)),
-                ValueType::VARINT => write_value(f, self.get_bytes(), |f, v| write!(f, "VARINT:{:?}", v)),
+                ValueType::VARINT => {
+                    write_value(f, self.get_bytes(), |f, v| write!(f, "VARINT:{:?}", v))
+                }
                 ValueType::BOOLEAN => write_value(f, self.get_bool(), |f, v| write!(f, "{}", v)),
                 ValueType::DOUBLE => write_value(f, self.get_f64(), |f, v| write!(f, "{}", v)),
                 ValueType::FLOAT => write_value(f, self.get_f32(), |f, v| write!(f, "{}", v)),
-                ValueType::BLOB => write_value(f, self.get_bytes(), |f, v| write!(f, "BLOB:{:?}", v)),
+                ValueType::BLOB => {
+                    write_value(f, self.get_bytes(), |f, v| write!(f, "BLOB:{:?}", v))
+                }
                 ValueType::INT => write_value(f, self.get_i32(), |f, v| write!(f, "{}", v)),
                 ValueType::SMALL_INT => write_value(f, self.get_i16(), |f, v| write!(f, "{}", v)),
                 ValueType::TINY_INT => write_value(f, self.get_i8(), |f, v| write!(f, "{}", v)),
                 ValueType::DURATION => write_value(f, self.get_i32(), |f, v| write!(f, "{:?}", v)),
-                ValueType::INET => write_value(f, self.get_inet(), |f, v| write!(f, "INET:{:?}", v)),
+                ValueType::INET => {
+                    write_value(f, self.get_inet(), |f, v| write!(f, "INET:{:?}", v))
+                }
                 ValueType::TIMESTAMP => write_value(f, self.get_i64(), |f, v| write!(f, "{}", v)),
-                ValueType::TIMEUUID => write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID:{}", v)),
+                ValueType::TIMEUUID => {
+                    write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID:{}", v))
+                }
                 ValueType::UUID => write_value(f, self.get_uuid(), |f, v| write!(f, "UUID:{}", v)),
-                ValueType::SET |
-                ValueType::LIST => write_set(f, self.get_set(), |f, i| write!(f, "{}, ", i)),
-                ValueType::MAP => write_map(f, self.get_map(), |f, k, v| write!(f, "{} => {}, ", k, v)),
+                ValueType::SET | ValueType::LIST => {
+                    write_set(f, self.get_set(), |f, i| write!(f, "{}, ", i))
+                }
+                ValueType::MAP => {
+                    write_map(f, self.get_map(), |f, k, v| write!(f, "{} => {}, ", k, v))
+                }
                 ValueType::UDT => write!(f, "<udt>"),
                 ValueType::TUPLE => write_set(f, self.get_set(), |f, i| write!(f, "{}, ", i)),
             }
@@ -270,7 +301,6 @@ impl Display for Value {
 }
 
 impl Value {
-
     /// Get the raw bytes of this Cassandra value.
     #[allow(cast_possible_truncation)]
     pub fn get_bytes(&self) -> Result<&[u8]> {
@@ -290,23 +320,29 @@ impl Value {
     //    }}
 
     /// Get the type of this Cassandra value
-    pub fn get_type(&self) -> ValueType { unsafe { ValueType::build(cass_value_type(self.0)) } }
+    pub fn get_type(&self) -> ValueType {
+        unsafe { ValueType::build(cass_value_type(self.0)) }
+    }
 
     /// Get the data type of this Cassandra value
-    pub fn data_type(&self) -> ConstDataType { unsafe { ConstDataType::build(cass_value_data_type(self.0)) } }
+    pub fn data_type(&self) -> ConstDataType {
+        unsafe { ConstDataType::build(cass_value_data_type(self.0)) }
+    }
 
     /// Returns true if a specified value is null.
-    pub fn is_null(&self) -> bool { unsafe { cass_value_is_null(self.0) == cass_true } }
+    pub fn is_null(&self) -> bool {
+        unsafe { cass_value_is_null(self.0) == cass_true }
+    }
 
     /// Returns true if a specified value is a collection.
-    pub fn is_collection(&self) -> bool { unsafe { cass_value_is_collection(self.0) == cass_true } }
-
+    pub fn is_collection(&self) -> bool {
+        unsafe { cass_value_is_collection(self.0) == cass_true }
+    }
 
     //    pub fn item_count(&self) -> u64 {
     //        unsafe { cass_value_item_count(self.0) }
     //    }
 
-
     // 	///Get the primary sub-type for a collection. This returns the sub-type for a
     // 	///list or set and the key type for a map.
     //    pub fn primary_sub_type(&self) -> ValueType {
@@ -348,7 +384,7 @@ impl Value {
                     } else {
                         Ok(MapIterator::build(iter))
                     }
-                },
+                }
                 _ => Err(CASS_ERROR_LIB_INVALID_VALUE_TYPE.to_error()),
             }
         }
@@ -366,7 +402,7 @@ impl Value {
                     } else {
                         Ok(UserTypeIterator::build(iter))
                     }
-                },
+                }
                 _ => Err(CASS_ERROR_LIB_INVALID_VALUE_TYPE.to_error()),
             }
         }
@@ -377,12 +413,13 @@ impl Value {
         unsafe {
             let mut message_ptr = mem::zeroed();
             let mut message_length = mem::zeroed();
-            cass_value_get_string(self.0, &mut message_ptr, &mut message_length).to_result(())
+            cass_value_get_string(self.0, &mut message_ptr, &mut message_length)
+                .to_result(())
                 .and_then(|_| {
-                    let slice = slice::from_raw_parts(message_ptr as *const u8, message_length as usize);
+                    let slice =
+                        slice::from_raw_parts(message_ptr as *const u8, message_length as usize);
                     Ok(str::from_utf8(slice)?)
-                }
-            )
+                })
         }
     }
 
@@ -395,8 +432,7 @@ impl Value {
     pub fn get_inet(&self) -> Result<Inet> {
         unsafe {
             let mut inet = mem::zeroed();
-            cass_value_get_inet(self.0, &mut inet)
-                .to_result(Inet::build(inet))
+            cass_value_get_inet(self.0, &mut inet).to_result(Inet::build(inet))
         }
     }
 
@@ -404,8 +440,7 @@ impl Value {
     pub fn get_i32(&self) -> Result<i32> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_int32(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_int32(self.0, &mut output).to_result(output)
         }
     }
 
@@ -413,8 +448,7 @@ impl Value {
     pub fn get_u32(&self) -> Result<u32> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_uint32(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_uint32(self.0, &mut output).to_result(output)
         }
     }
 
@@ -422,8 +456,7 @@ impl Value {
     pub fn get_i16(&self) -> Result<i16> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_int16(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_int16(self.0, &mut output).to_result(output)
         }
     }
 
@@ -431,8 +464,7 @@ impl Value {
     pub fn get_i8(&self) -> Result<i8> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_int8(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_int8(self.0, &mut output).to_result(output)
         }
     }
 
@@ -440,8 +472,7 @@ impl Value {
     pub fn get_i64(&self) -> Result<i64> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_int64(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_int64(self.0, &mut output).to_result(output)
         }
     }
 
@@ -449,8 +480,7 @@ impl Value {
     pub fn get_f32(&self) -> Result<f32> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_float(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_float(self.0, &mut output).to_result(output)
         }
     }
 
@@ -458,8 +488,7 @@ impl Value {
     pub fn get_f64(&self) -> Result<f64> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_double(self.0, &mut output)
-                .to_result(output)
+            cass_value_get_double(self.0, &mut output).to_result(output)
         }
     }
 
@@ -467,8 +496,7 @@ impl Value {
     pub fn get_bool(&self) -> Result<bool> {
         unsafe {
             let mut output = mem::zeroed();
-            cass_value_get_bool(self.0, &mut output)
-                .to_result(output == cass_true)
+            cass_value_get_bool(self.0, &mut output).to_result(output == cass_true)
         }
     }
 
@@ -476,8 +504,7 @@ impl Value {
     pub fn get_uuid(&self) -> Result<Uuid> {
         unsafe {
             let mut uuid = mem::zeroed();
-            cass_value_get_uuid(self.0, &mut uuid)
-                .to_result(Uuid::build(uuid))
+            cass_value_get_uuid(self.0, &mut uuid).to_result(Uuid::build(uuid))
         }
     }
 }
